@@ -54,10 +54,14 @@ def _getExtentHandler(args: Namespace, nbdClient):
     if args.qemu:
         logging.info("Using qemu tools to query extents")
         extentHandler = extenthandler.ExtentHandler(
-            qemu.util(nbdClient.cType.exportName), nbdClient.cType
+            qemu.util(nbdClient.cType.exportName),
+            nbdClient.cType,
+            args.no_sparse_detection,
         )
     else:
-        extentHandler = extenthandler.ExtentHandler(nbdClient, nbdClient.cType)
+        extentHandler = extenthandler.ExtentHandler(
+            nbdClient, nbdClient.cType, args.no_sparse_detection
+        )
 
     return extentHandler
 
@@ -105,8 +109,12 @@ def backup(  # pylint: disable=too-many-arguments,too-many-branches, too-many-lo
     thinBackupSize = sum(extent.length for extent in extents if extent.data is True)
     logging.info("Got %s extents to backup.", len(extents))
     logging.debug("%s", lib.dumpExtentJson(extents))
-    logging.info("%s bytes disk size", diskSize)
-    logging.info("%s bytes of data extents to backup", thinBackupSize)
+    logging.info("%s bytes [%s] virtual disk size", diskSize, lib.humanize(diskSize))
+    logging.info(
+        "%s bytes [%s] of data extents to backup",
+        thinBackupSize,
+        lib.humanize(thinBackupSize),
+    )
 
     if args.level in ("inc", "diff") and thinBackupSize == 0:
         logging.info("No dirty blocks found")
@@ -217,6 +225,7 @@ def backup(  # pylint: disable=too-many-arguments,too-many-branches, too-many-lo
                 "Backup of disk [%s] finished, file: [%s]", disk.target, targetFile
             )
         partialfile.rename(targetFilePartial, targetFile)
+    if streamType != "raw":
         backupChecksum(fileStream, targetFile)
 
     return backupSize, True
